@@ -237,7 +237,7 @@ class VCSStorage(storages.Storage):
     def entity_added(self, entity, attr):
         """an entity using this storage for attr has been added"""
         try:
-            data = entity.pop(attr)
+            data = entity.cw_edited.pop(attr)
         except KeyError:
             pass
         else:
@@ -256,7 +256,7 @@ class VCSStorage(storages.Storage):
                 vcsrepohdlr.add_versioned_file_content(session, transaction,
                                                        vf, entity, data)
             vckey = (str(repoeid), dir, name, str(revnum))
-            entity[attr] = Binary('\x01'.join(vckey))
+            entity.cw_edited[attr] = Binary('\x01'.join(vckey))
 
     def entity_updated(self, entity, attr):
         """an entity using this storage for attr has been updatded"""
