@@ -15,8 +15,7 @@ from logilab.mtconverter import need_guess, guess_mimetype_and_encoding
 
 from cubicweb import QueryError, ValidationError, Binary
 from cubicweb.server import hook
-from cubicweb.server.hook import Hook, Operation, set_operation
-from cubicweb.selectors import is_instance, score_entity
+from cubicweb.selectors import is_instance, score_entity, configuration_values
 
 from cubes.vcsfile import IMMUTABLE_ATTRIBUTES, bridge
 
@@ -53,7 +52,7 @@ def set_local_cache(vcsrepo):
             vcsrepo.exception('cant create repo cache directory %s', cachedir)
             return
     try:
-        vcsrepo['local_cache'] = osp.join(
+        vcsrepo.cw_edited['local_cache'] = osp.join(
             unicode(vcsrepo.eid), url_to_relative_path(vcsrepo.source_url))
     except (IndexError, ValueError):
         # do nothing, validation error should be raised by another hook
@@ -91,7 +90,7 @@ def missing_attribute_error(entity, attrs):
 
 # initialization hooks #########################################################
 
-class ServerMaintenanceHook(Hook):
+class ServerMaintenanceHook(hook.Hook):
     """install attribute map on the system source sql generator
     """
     __regid__ = 'vcsfile.servermaintenancehook'
@@ -102,11 +101,16 @@ class ServerMaintenanceHook(Hook):
                                        bridge.VCSStorage())
 
 
-class ServerStartupHook(Hook):
+class ServerStartupHook(hook.Hook):
     """synchronize repository on server startup, and install attribute map
     on the system source sql generator
     """
     __regid__ = 'vcsfile.serverstartuphook'
+    __select__ = hook.Hook.__select__ & (
+        configuration_values('import-revision-content', True)
+        | configuration_values('repository-import', True)
+        )
+
     events = ('server_startup',)
     def __call__(self):
         repo = self.repo
@@ -160,7 +164,7 @@ class ServerStartupHook(Hook):
 
 # internals to be able to create new vcs repo revision using rql queries #######
 
-class VCTransactionOp(Operation):
+class VCTransactionOp(hook.Operation):
 
     def precommit_event(self):
         bridge.set_at_revision(self.session, self.revision.eid)
@@ -173,7 +177,7 @@ class VCTransactionOp(Operation):
         for transaction in transactions.itervalues():
             transaction.rollback()
 
-    def commit_event(self):
+    def postcommit_event(self):
         transactions = self.session.transaction_data.setdefault('vctransactions', {})
         for transaction in transactions.itervalues():
             transaction.commit()
@@ -184,45 +188,42 @@ class VCTransactionOp(Operation):
             transaction.rollback()
 
 
-class VFModificationDateOp(Operation):
+class VFModificationDateOp(hook.DataOperationMixIn, hook.Operation):
     def precommit_event(self):
-        for entity in self.session.transaction_data.pop('vcsfile.modifiedvfs'):
+        for entity in self.get_data():
             entity.file.set_attributes(modification_date=entity.rev.creation_date)
 
 
-class UpdateVFModificationDateHook(Hook):
+class UpdateVFModificationDateHook(hook.Hook):
     __regid__ = 'vcsfile.update_vf_mdate'
-    __select__ = Hook.__select__ & is_instance('DeletedVersionContent',
+    __select__ = hook.Hook.__select__ & is_instance('DeletedVersionContent',
                                                'VersionContent')
     events = ('after_add_entity',)
 
     def __call__(self):
-        set_operation(self._cw, 'vcsfile.modifiedvfs', self.entity,
-                      VFModificationDateOp)
+        VFModificationDateOp.get_instance(self._cw).add_data(self.entity)
 
 
-class AddRevisionHook(Hook):
+class AddRevisionHook(hook.Hook):
     __regid__ = 'vcsfile.add_revision_hook'
-    __select__ = Hook.__select__ & is_instance('Revision')
+    __select__ = hook.Hook.__select__ & is_instance('Revision')
     events = ('before_add_entity',)
 
     def __call__(self):
         entity = self.entity
         session = self._cw
-        if not entity.get('revision'):
-            # new revision to be created, set a temporary value
-            entity['revision'] = 0
+        # new revision to be created, set a temporary value if necessary
+        revision = entity.cw_edited.setdefault('revision', 0)
         # skip further processing if the revision is being imported from the
         # vcs repository
         if session.is_internal_session:
             return
         try:
-            vcsrepoeid = entity['from_repository']
+            vcsrepoeid = entity.cw_attr_cache['from_repository']
         except KeyError:
             vcsrepoeid = session.transaction_data.pop('vcsrepoeid', None)
             if vcsrepoeid is None:
                 raise missing_relation_error(entity, 'from_repository')
-        revision = entity.get('revision', 0)
         if revision > 0: # set to 0 by hook
             raise QueryError("can't specify revision")
         transactions = session.transaction_data.setdefault('vctransactions', {})
@@ -234,33 +235,32 @@ class AddRevisionHook(Hook):
         transaction = vcsrepohdlr.revision_transaction(session, entity)
         transaction.reveid = entity.eid
         transactions[vcsrepoeid] = transaction
-        entity['revision'] = transaction.rev
+        entity.cw_edited['revision'] = transaction.rev
         VCTransactionOp(session, revision=entity)
 
 
-class AddVersionContentHook(Hook):
+class AddVersionContentHook(hook.Hook):
     __regid__ = 'vcsfile.add_version_content_hook'
-    __select__ = Hook.__select__ & is_instance('VersionContent')
+    __select__ = hook.Hook.__select__ & is_instance('VersionContent')
     events = ('before_add_entity',)
 
     def __call__(self):
-        session = self._cw
-        entity = self.entity
-        if need_guess(entity.get('data_format'), entity.get('data_encoding')):
-            vf = entity._vc_vf()
+        edited = self.entity.cw_edited
+        if need_guess(edited.get('data_format'), edited.get('data_encoding')):
+            vf = self.entity._vc_vf()
             encoding = vf.repository.encoding
-            mt, enc = guess_mimetype_and_encoding(data=entity.get('data'),
+            mt, enc = guess_mimetype_and_encoding(data=edited.get('data'),
                                                   filename=vf.name,
                                                   fallbackencoding=encoding)
-            if mt and not entity.get('data_format'):
-                entity['data_format'] = unicode(mt)
-            if enc and not entity.get('data_encoding'):
-                entity['data_encoding'] = unicode(enc)
+            if mt and not edited.get('data_format'):
+                edited['data_format'] = unicode(mt)
+            if enc and not edited.get('data_encoding'):
+                edited['data_encoding'] = unicode(enc)
 
 
-class AddDeletedVersionContentHook(Hook):
+class AddDeletedVersionContentHook(hook.Hook):
     __regid__ = 'vcsfile.add_deleted_version_content_hook'
-    __select__ = Hook.__select__ & is_instance('DeletedVersionContent')
+    __select__ = hook.Hook.__select__ & is_instance('DeletedVersionContent')
     events = ('before_add_entity',)
 
     def __call__(self):
@@ -274,9 +274,9 @@ class AddDeletedVersionContentHook(Hook):
                                                        self.entity)
 
 
-class AddVersionedFileHook(Hook):
+class AddVersionedFileHook(hook.Hook):
     __regid__ = 'vcsfile.add_versioned_file_hook'
-    __select__ = Hook.__select__ & is_instance('VersionedFile')
+    __select__ = hook.Hook.__select__ & is_instance('VersionedFile')
     events = ('before_add_entity',)
 
     def __call__(self):
@@ -287,12 +287,12 @@ class AddVersionedFileHook(Hook):
         CheckVersionedFileOp(self._cw, entity=self.entity)
 
 
-class SetRepoCacheBeforeAdd(Hook):
+class SetRepoCacheBeforeAddHook(hook.Hook):
     """clone just after repo creation
     mostly helps the tests
     """
     __regid__ = 'clone_hgrepo_after_add'
-    __select__ = (Hook.__select__ & is_instance('Repository'))
+    __select__ = (hook.Hook.__select__ & is_instance('Repository'))
     events = ('before_add_entity',)
     order = 2
 
@@ -302,12 +302,12 @@ class SetRepoCacheBeforeAdd(Hook):
             set_local_cache(repo)
 
 
-class CloneRepoAfterAdd(Hook):
+class CloneRepoAfterAddHook(hook.Hook):
     """clone just after repo creation, to allow operation which needs local
     access and get quicker checkout if test are running on the same host
     """
     __regid__ = 'clone_hgrepo_after_add'
-    __select__ = (Hook.__select__ & is_instance('Repository'))
+    __select__ = (hook.Hook.__select__ & is_instance('Repository'))
     events = ('after_add_entity',)
     order = 2
 
@@ -319,19 +319,19 @@ class CloneRepoAfterAdd(Hook):
         clone_to_local_cache(vcsrepo)
 
 
-class UpdateRepositoryHook(Hook):
+class UpdateRepositoryHook(hook.Hook):
     """add repository eid to vcs bridge cache"""
     __regid__ = 'vcsfile.update_repository_hook'
-    __select__ = Hook.__select__ & is_instance('Repository')
+    __select__ = hook.Hook.__select__ & is_instance('Repository')
     events = ('before_update_entity', )
 
     def __call__(self):
         vcsrepo = self.entity
-        if 'type' in vcsrepo.edited_attributes:
+        if 'type' in vcsrepo.cw_edited:
             msg = self._cw._('updating type attribute of a repository isn\'t '
                              'supported. Delete it and add a new one.')
             raise ValidationError(vcsrepo.eid, {'type': msg})
-        if 'path' in vcsrepo.edited_attributes or 'local_cache' in vcsrepo.edited_attributes:
+        if 'path' in vcsrepo.cw_edited or 'local_cache' in vcsrepo.cw_edited:
             bridge._REPOHDLRS.pop(vcsrepo.eid, None)
         if (vcsrepo.type == 'mercurial' and vcsrepo.source_url
             and not vcsrepo.path and not vcsrepo.local_cache):
@@ -340,9 +340,19 @@ class UpdateRepositoryHook(Hook):
             clone_to_local_cache(vcsrepo)
 
 
-class DeleteRepositoryHook(Hook):
+class DeleteDirsOp(hook.DataOperationMixIn, hook.Operation):
+
+    def postcommit_event(self):
+        for cachedir in self.get_data():
+            try:
+                shutil.rmtree(cachedir)
+                self.info('deleted repository cache at %s', cachedir)
+            except:
+                self.exception('cant delete repository cache at %s', cachedir)
+
+class DeleteRepositoryHook(hook.Hook):
     __regid__ = 'vcsfile.add_update_repository_hook'
-    __select__ = (Hook.__select__ &
+    __select__ = (hook.Hook.__select__ &
                   is_instance('Repository') &
                   score_entity(lambda x:x.local_cache))
     events = ('before_delete_entity',)
@@ -352,18 +362,7 @@ class DeleteRepositoryHook(Hook):
             cachedir = osp.dirname(osp.join(
                 self._cw.vreg.config['local-repo-cache-root'],
                 self.entity.local_cache)).encode('ascii')
-            set_operation(self._cw, 'vcsfile.deletedirs', cachedir,
-                          DeleteDirsOp)
-
-class DeleteDirsOp(Operation):
-
-    def postcommit_event(self):
-        for cachedir in self.session.transaction_data.pop('vcsfile.deletedirs'):
-            try:
-                shutil.rmtree(cachedir)
-                self.info('deleted repository cache at %s', cachedir)
-            except:
-                self.exception('cant delete repository cache at %s', cachedir)
+            DeleteDirsOp.get_instance(self._cw).add_data(cachedir)
 
 
 # safety belts #################################################################
@@ -385,14 +384,14 @@ def _check_in_transaction(vf_or_rev):
     return transaction
 
 
-class CheckVersionedFileOp(Operation):
+class CheckVersionedFileOp(hook.Operation):
     """check transaction consistency when adding new revision using rql queries
     """
     def precommit_event(self):
         _check_in_transaction(self.entity)
 
 
-class CheckRevisionOp(Operation):
+class CheckRevisionOp(hook.Operation):
     """check transaction consistency when adding new revision using rql queries
     """
     def precommit_event(self):
@@ -405,9 +404,9 @@ class CheckRevisionOp(Operation):
             raise QueryError('entity linked to a bad revision')
 
 
-class CheckImmutableAttributeHook(Hook):
+class CheckImmutableAttributeHook(hook.Hook):
     __regid__ = 'vcsfile.check_immutable_attribute_hook'
-    __select__ = Hook.__select__ & is_instance(
+    __select__ = hook.Hook.__select__ & is_instance(
         'Revision', 'DeletedVersionContent', 'VersionContent')
     events = ('before_update_entity',)
 
@@ -419,9 +418,9 @@ class CheckImmutableAttributeHook(Hook):
                 raise QueryError('%s attribute is not editable' % attr)
 
 
-class AddUpdateRepositoryHook(Hook):
+class AddUpdateRepositoryHook(hook.Hook):
     __regid__ = 'vcsfile.add_update_repository_hook'
-    __select__ = Hook.__select__ & is_instance('Repository')
+    __select__ = hook.Hook.__select__ & is_instance('Repository')
     events = ('after_add_entity', 'after_update_entity')
     required_attrs = ('path', 'source_url')
     order = 1
@@ -445,13 +444,13 @@ class AddUpdateRepositoryHook(Hook):
 
 # folder/tag extensions ########################################################
 
-class ClassifyVersionedFileHook(Hook):
+class ClassifyVersionedFileHook(hook.Hook):
     """classifies VersionedFile automatically according to their path in the
     repository (require cubicweb-tag and/or cubicweb-folder installed)
     """
     __regid__ = 'vcsfile.classify_versioned_file_hook'
     events = ('after_add_entity', )
-    __select__ = Hook.__select__ & is_instance('VersionedFile')
+    __select__ = hook.Hook.__select__ & is_instance('VersionedFile')
 
     def __call__(self):
         try:
