@@ -4,6 +4,9 @@
 :copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
+
+from __future__ import with_statement
+
 __docformat__ = "restructuredtext en"
 
 from os import umask, makedirs
@@ -14,6 +17,7 @@ from mercurial import hg, ui, revlog, context, util, commands as hgcmd
 from mercurial.node import nullid, short as short_hex
 
 from cubicweb import Binary, QueryError
+from cubicweb.server.ssplanner import EditedEntity
 
 from cubes.vcsfile import repo, bridge
 from cubes.vcsfile.entities import remove_authinfo
@@ -276,11 +280,11 @@ class HGTransaction(object):
     def _commit(self):
         # XXX merging branches
         encode = self.repohdlr.encode
-        branch = encode(self.revision.get('branch') or u'default')
+        branch = encode(self.revision.cw_attr_cache.get('branch') or u'default')
         if branch != u'default':
             self.extra['branch'] = branch
-        author = encode(self.revision.get('author', u''))
-        msg = encode(self.revision.get('description', u''))
+        author = encode(self.revision.cw_attr_cache.get('author', u''))
+        msg = encode(self.revision.cw_attr_cache.get('description', u''))
         try:
             p1 = self.repo.branchtags()[branch]
         except KeyError:
@@ -310,11 +314,10 @@ class HGTransaction(object):
         # take care, self.repo != self.session.repo (eg mercurial repo instance
         # / rql repository)
         source = self.session.repo.system_source
-         # remove previous cached value to only save the changeset
-        self.revision.clear()
-        self.revision.edited_attributes = set()
-        self.revision['changeset'] = unicode(short_hex(node))
-        source.update_entity(self.session, self.revision)
+        # remove previous cached value to only save the changeset
+        with setattrcm(self.revision, 'cw_edited', EditedEntity(self.revision)) as rev:
+            rev.cw_edited['changeset'] = unicode(short_hex(node))
+            source.update_entity(self.session, rev)
         # XXX restore entity's dict?
         self.rollback()
 
@@ -327,6 +330,23 @@ class HGTransaction(object):
             del self._wlock
             del self._lock
 
+
+
+class setattrcm(object):
+    def __init__(self, obj, attr, value):
+        self.obj = obj
+        self.attr = attr
+        self.value = value
+
+    def __enter__(self):
+        self.old = getattr(self.obj, self.attr)
+        setattr(self.obj, self.attr, self.value)
+        return self.obj
+
+    def __exit__(self, exctype, value, traceback):
+        setattr(self.obj, self.attr, self.old)
+
+
 from logging import getLogger
 from cubicweb import set_log_methods
 set_log_methods(HGRepository, getLogger('cubicweb.sources.hg'))
