@@ -94,7 +94,7 @@ class VersionedFile(EntityType):
     directory = String(required=True, indexed=True,
                        description=_('directory of the file in the repository.'),
                    __permissions__=RO_ATTRPERMS)
-    name = String(required=True,
+    name = String(required=True, fulltextindexed=True,
                   description=_('name of the file in the repository.'),
                    __permissions__=RO_ATTRPERMS)
 
