@@ -37,7 +37,9 @@ should be commited (default to 1, e.g. on each revision).',
          {'type' : 'yn',
           'default': True,
           'help': 'Import content of file touched by a revision. This may \
-cause performance issue when scaling.',
+cause performance issue when scaling. Should be set correctly even if the \
+instance is not the instance responsible to import repositories\' content \
+(e.g. repository-import=no).',
           'level': 2,
           'group': 'vcsfile',
           }),
