@@ -6,10 +6,10 @@ from os.path import exists
 
 from cubicweb.web.views import actions, primary, idownloadable
 
+from utils import VCSFileTC, remove_eid # import first to setup import machinery
 from cubes.vcsfile import entities
 from cubes.vcsfile.views import primary as svnfviews, actions as vcsactions
 
-from utils import VCSFileTC, remove_eid
 
 
 class VCViewsTC(VCSFileTC):
@@ -42,8 +42,7 @@ class VCViewsTC(VCSFileTC):
         req = self.request()
         v1rset = req.execute('Any X WHERE X from_revision R, R revision 1, X content_for VF, VF name "toto.txt"')
         self.assertEqual(self.pactions(req, v1rset),
-                          [('edit', actions.ModifyAction),
-                           ('managepermission', actions.ManagePermissionsAction),
+                          [('managepermission', actions.ManagePermissionsAction),
                            ('addrelated', actions.AddRelatedActions),
                            ('revhead', vcsactions.VCHeadRevisionAction),
                            ('revall', vcsactions.VCAllRevisionsAction),
@@ -52,8 +51,7 @@ class VCViewsTC(VCSFileTC):
                            ('revallfiles', vcsactions.VCRevisionAllFilesAction)])
         v2rset = req.execute('Any X WHERE X from_revision R, R revision 2, X content_for VF, VF name "toto.txt"')
         self.assertEqual(self.pactions(req, v2rset),
-                          [('edit', actions.ModifyAction),
-                           ('managepermission', actions.ManagePermissionsAction),
+                          [('managepermission', actions.ManagePermissionsAction),
                            ('addrelated', actions.AddRelatedActions),
                            ('revall', vcsactions.VCAllRevisionsAction),
 #                           ('revprev', vcsactions.VCPreviousRevisionAction),
@@ -61,8 +59,7 @@ class VCViewsTC(VCSFileTC):
                            ('revallfiles', vcsactions.VCRevisionAllFilesAction)])
         v3rset = req.execute('Any X WHERE X from_revision R, R revision 3, X content_for VF, VF name "data.bin.gz"')
         self.assertEqual(self.pactions(req, v2rset),
-                          [('edit', actions.ModifyAction),
-                           ('managepermission', actions.ManagePermissionsAction),
+                          [('managepermission', actions.ManagePermissionsAction),
                            ('addrelated', actions.AddRelatedActions),
                            ('revall', vcsactions.VCAllRevisionsAction),
 #                           ('revprev', vcsactions.VCPreviousRevisionAction),
