@@ -26,6 +26,7 @@ _abaa = uicfg.actionbox_appearsin_addmenu
 _pvs.tag_subject_of(('*', 'at_revision', '*'), 'hidden')
 _pvs.tag_object_of(('*', 'at_revision', '*'), 'hidden')
 _pvs.tag_attribute(('Repository', 'local_cache'), 'hidden')
+_pvs.tag_object_of(('*', 'from_repository', 'Repository'), 'hidden')
 
 _pvs.tag_attribute(('VersionedFile', 'name'), 'hidden') # in title
 _pvs.tag_attribute(('VersionedFile', 'directory'), 'hidden') # in title
@@ -75,7 +76,7 @@ class RepositoryPrimaryView(tabs.TabsMixin, primary.PrimaryView):
         self.render_tabs(self.tabs, self.default_tab, entity)
 
 
-class RepositoryInfoTab(primary.PrimaryView):
+class RepositoryInfoTab(tabs.PrimaryTab):
     __regid__ = 'repositoryinfo_tab'
     __select__ = is_instance('Repository')
 
